from django.template.loader import render_to_string

def koModel(model):

    modelName = model.__name__
    fields = model._meta.get_all_field_names()
    modelViewString = render_to_string("knockout_modeler/model.html", {'modelName': modelName, 'fields': fields} )

    return modelViewString



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-knockout-modeler',
    version='0.1.0',
    packages=['knockout_modeler'],
    install_requires=[
    ],
    include_package_data=True,
    license='MIT License',
    description='Super easy ModelViews for knockout.js for your Django models',
    long_description=README,
    url='https://github.com/Miserlou/django-knockout-modeler',
    author='Rich Jones',
    author_email='rich@openwatch.net',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
